import { ApiProperty } from '@nestjs/swagger'
import { IsEmail, IsNotEmpty } from 'class-validator'

export enum EmailScene {
  register = 'register',
  forgetPassword = 'forgetPassword',
  changeEmail = 'changeEmail',
  deleteUser = 'deleteUser',
}

export class EmailSendDto {
  @IsNotEmpty()
  @IsEmail()
  email: string

  @IsNotEmpty()
  @ApiProperty({ enum: EmailScene, enumName: 'EmailScene' })
  scene: EmailScene
}

export class EmailVerifyDto {
  @IsNotEmpty()
  @IsEmail()
  email: string

  /** @description 发送邮箱接口返回的Token */
  @IsNotEmpty()
  token: string

  /** @description 邮箱验证码 */
  @IsNotEmpty()
  verifyCode: string
}

export class EmailVerifycationDto extends EmailVerifyDto {
  @IsNotEmpty()
  scene: EmailScene
}
